@@ -6,25 +6,29 @@ class AioSQLiteAdapter:
 
     def process_sql(self, _query_name, _op_type, sql):
         """Pass through function because the ``aiosqlite`` driver can already handle the
-        :var_name format used by aiosql and doesn't need any additional processing.
+        ``:var_name`` format used by aiosql and doesn't need any additional processing.
 
         Args:
-            _query_name (str): The name of the sql query.
-            _op_type (SQLOperationType): The type of SQL operation performed by the query.
-            sql (str): The sql as written before processing.
+
+        - _query_name (str): The name of the sql query.
+        - _op_type (SQLOperationType): The type of SQL operation performed by the query.
+        - sql (str): The sql as written before processing.
 
         Returns:
-            str: Original SQL text unchanged.
+
+        - str: Original SQL text unchanged.
         """
         return sql
 
     async def select(self, conn, _query_name, sql, parameters, record_class=None):
         async with conn.execute(sql, parameters) as cur:
-            results = await cur.fetchall()
             if record_class is not None:
                 column_names = [c[0] for c in cur.description]
-                results = [record_class(**dict(zip(column_names, row))) for row in results]
-        return results
+                for row in await cur.fetchall():
+                    yield record_class(**dict(zip(column_names, row)))
+            else:
+                for row in await cur.fetchall():
+                    yield row
 
     async def select_one(self, conn, _query_name, sql, parameters, record_class=None):
         async with conn.execute(sql, parameters) as cur:
@@ -49,8 +53,8 @@ class AioSQLiteAdapter:
             return cur.lastrowid
 
     async def insert_update_delete(self, conn, _query_name, sql, parameters):
-        cur = await conn.execute(sql, parameters)
-        await cur.close()
+        async with conn.execute(sql, parameters) as cur:
+            return cur.rowcount
 
     async def insert_update_delete_many(self, conn, _query_name, sql, parameters):
         cur = await conn.executemany(sql, parameters)
