@@ -2,9 +2,12 @@ from .generic import GenericAdapter
 
 
 class SQLite3Adapter(GenericAdapter):
-    # overwrites some methods using sqlite3-specific non-standard methods
+    """SQLite3 Adapter for AioSQL.
 
-    def insert_returning(self, conn, _query_name, sql, parameters):
+    Overwrites two methods using sqlite3-specific non-standard methods.
+    """
+
+    def insert_returning(self, conn, query_name, sql, parameters):
         cur = self._cursor(conn)
         try:
             cur.execute(sql, parameters)
